@@ -196,7 +196,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard) {
  * =====================================================================*/
 static void colors_next_level() {
   gchar *str = NULL;
-  int i;
+  int i, list_length;
   GList * list = NULL;
   int * item;
 
@@ -215,8 +215,8 @@ static void colors_next_level() {
     for (i=0; i<LAST_COLOR; i++)
       list = g_list_append(list, GINT_TO_POINTER(i));
 
-    while ((g_list_length(list) > 0)) {
-      i = RAND(0,g_list_length(list)-1);
+    while((list_length = g_list_length(list))) {
+      i = list_length == 1 ? 0 : g_random_int_range(0,g_list_length(list)-1);
       item = g_list_nth_data(list, i);
       listColors = g_list_append(listColors, item);
       list = g_list_remove(list, item);
@@ -288,7 +288,7 @@ static GnomeCanvasItem *colors_create_item(GnomeCanvasGroup *parent) {
 
   g_free(str);
   gnome_canvas_item_hide(highlight_image_item);
-  i = RAND(0,LAST_COLOR);
+  i = g_random_int_range(0,LAST_COLOR);
 
   gdk_pixbuf_unref(highlight_pixmap);
 
@@ -322,7 +322,7 @@ static void game_won() {
     gcomprisBoard->level++;
     gcomprisBoard->sublevel = 1;
     if (gcomprisBoard->level > gcomprisBoard->maxlevel) {
-      gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
+      gc_bonus_end_display(GC_BOARD_FINISHED_TUXLOCO);
       return;
     }
 
@@ -338,7 +338,7 @@ static void game_won() {
  * =====================================================================*/
 static gboolean ok_timeout() {
   g_warning("+++ ok_timeout errors = %d\n", errors);
-  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
   if (!gamewon)
     errors--;
   if (errors <1)
@@ -346,7 +346,7 @@ static gboolean ok_timeout() {
   update_clock();
 
   if (errors <= 1) {
-    gc_bonus_end_display(BOARD_FINISHED_TOOMANYERRORS);
+    gc_bonus_end_display(GC_BOARD_FINISHED_TOOMANYERRORS);
   }
 
   return FALSE;
@@ -384,6 +384,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
 	}
       }
       if (clicked >= 0) {
+	gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 	board_paused = TRUE;
 	highlight_selected(clicked);
 	gamewon = (clicked == GPOINTER_TO_INT(g_list_nth_data(listColors,0)));
