@@ -38,7 +38,7 @@
 
 #define LOCK_WIDTH		20
 #define LOCK_HEIGHT_MAX		(RIGHT_CANAL_HEIGHT + 40)
-#define LOCK_HEIGHT_MIN		20
+#define LOCK_HEIGHT_MIN		60
 
 #define SUBCANAL_BASE_LINE	(BASE_LINE + 80)
 #define SUBCANAL_HEIGHT		40
@@ -444,10 +444,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   canal_lock_next_level();
 }
@@ -494,6 +494,8 @@ static void move_boat()
       return;
     }
 
+  gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
+
   gnome_canvas_item_get_bounds(tuxboat_item, &timer_item_x1, &timer_item_y1,
 			       &timer_item_x2, &timer_item_y2);
 
@@ -556,6 +558,8 @@ static void toggle_lock(GnomeCanvasItem *item)
     return;
   animation = TRUE;
 
+  gc_sound_play_ogg ("sounds/bleep.wav", NULL);
+
   gnome_canvas_item_get_bounds(item, &timer_item_x1, &timer_item_y1,
 			       &timer_item_x2, &timer_item_y2);
 
@@ -760,7 +764,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   /*
     gamewon = TRUE;
     canal_lock_destroy_all_items();
-    gc_bonus_display(gamewon, BONUS_SMILEY);
+    gc_bonus_display(gamewon, GC_BONUS_SMILEY);
   */
   return FALSE;
 }
